﻿using System;
using Android.App;
using Android.Content;
using Android.Runtime;
using Android.Views;
using Android.Widget;
using Android.OS;
using Com.Syncfusion.Charts;
using Android.Graphics;
using Android.Util;
using Com.Syncfusion.Charts.Enums;
using System.Collections.Generic;
using Android.Database;
using Java.IO;
using Java.Sql;
using System.Data.SqlClient;
using Java.Util;
using Com.Syncfusion.Rangenavigator;
using System.Threading.Tasks;

namespace ChartSample
{
    [Activity(Label = "ChartSample", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        ObservableArrayList data = new ObservableArrayList(); 
        DateTimeAxis primaryAxis = new DateTimeAxis();

        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);

            SetContentView(Resource.Layout.Main);

            LinearLayout layout = new LinearLayout(this);
            layout.Orientation = Android.Widget.Orientation.Vertical;

            UpdateData();
            
            layout.AddView(GetChart());
            layout.AddView(GetRangeNavigator());

            SetContentView(layout);
        }

        private SfChart GetChart()
        {
            SfChart chart = new SfChart(this);
            chart.LayoutParameters = new ViewGroup.LayoutParams(520, 500);
            chart.SetBackgroundColor(Color.White);
            primaryAxis.IntervalType = DateTimeIntervalType.Minutes;
            primaryAxis.Interval = 5;
            primaryAxis.LabelStyle.LabelFormat = "HH:mm aa";
            NumericalAxis secondaryAxis = new NumericalAxis();

            chart.PrimaryAxis = primaryAxis;
            chart.SecondaryAxis = secondaryAxis;

            SplineSeries series = new SplineSeries();
            series.DataSource = data;
            chart.Series.Add(series);

            chart.Behaviors.Add(new ChartZoomPanBehavior() { ZoomMode = ZoomMode.X, DoubleTapEnabled = false });
            ChartTrackballExt track = new ChartTrackballExt();
            
            chart.Behaviors.Add(track);

            return chart;
        }

        private SfDateTimeRangeNavigator GetRangeNavigator()
        {
            SfDateTimeRangeNavigator rangeNavigator = new SfDateTimeRangeNavigator(this);
            rangeNavigator.SetBackgroundColor(Color.White);
            rangeNavigator.TooltipFormat = "HH:mm aa";
            rangeNavigator.LayoutParameters = new ViewGroup.LayoutParams(520, 230);
            rangeNavigator.Minimum = new GregorianCalendar(2016, 0, 1, 4, 0).Time;
            rangeNavigator.Maximum = new GregorianCalendar(2016, 0, 2, 4, 0).Time;
            
            rangeNavigator.RangeChanged += RangeNavigator_RangeChanged;
            (rangeNavigator.Content as SfChart).Series.Add(new SplineSeries() { DataSource = data });

            return rangeNavigator;
        }

        private void RangeNavigator_RangeChanged(object sender, SfDateTimeRangeNavigator.RangeChangedEventArgs e)
        {
            primaryAxis.Minimum = e.P0;
            primaryAxis.Maximum = e.P1;
        }

        private async void UpdateData()
        {
            GregorianCalendar calendar = new GregorianCalendar(2016, 0, 1, 4, 0);
            System.Random random = new System.Random();
            await Task.Delay(2000);
            for(int i = 0; i < 288; i++)
            {
                data.Add(new ChartDataPoint(calendar.Time, random.NextDouble() * 100));
                AddMinutes(calendar, 5);
            }
        }

        Calendar AddMinutes(Calendar calendar,int minutes)
        {
            calendar.Add(CalendarField.Minute, minutes);
            return calendar;
        }
    }

    public class ChartTrackballExt : ChartTrackballBehavior
    {
        protected override void OnTouchDown(float p0, float p1)
        {
            base.OnTouchDown(p0, p1);
            this.Show(p0, p1);
        }
    }
}

